@@ -11,8 +11,8 @@ import (
 type Interface interface {
 	GetName() string
 	Add(item *Item) error
-	Get(name string) (*Item, error)
-	List() ([]*Item, error)
+	Get(options GetOptions) (*Item, error)
+	List(options ListOptions) ([]*Item, error)
 }
 
 // Field is custom fields under Item.
@@ -21,21 +21,45 @@ type Field struct {
 	Value string `json:"value"`
 }
 
+// GetOptions is options for Get method.
+type GetOptions struct {
+	Name   string
+	Bucket *string
+}
+
+// ListOptions is options for List method.
+type ListOptions struct {
+	Bucket *string
+}
+
 // Item is a secure item of provider.
 type Item struct {
 	ID     string  `json:"id,omitempty"`
 	Name   string  `json:"name"`
 	Values []Field `json:"value"`
+	Bucket *string
 }
 
 // EncodeValues encodes Values.
 func (i Item) EncodeValues() (string, error) {
-	var p []byte
+	var values []byte
 
-	p, err := json.Marshal(i.Values)
+	values, err := i.MarshalValues()
 	if err != nil {
 		return "", err
 	}
 
-	return base64.StdEncoding.EncodeToString(p), nil
+	return base64.StdEncoding.EncodeToString(values), nil
+}
+
+// MarshalValues encodes the Values to JSON bytes.
+func (i Item) MarshalValues() ([]byte, error) {
+	var values []byte
+
+	values, err := json.Marshal(i.Values)
+	if err != nil {
+		return nil, err
+	}
+
+	return values, nil
 }
